@@ -183,6 +183,11 @@ static void partition_data (
    size_t num_cell_ids, size_t threshold, struct sphere_part_node * parent_node,
    double prev_gc_norm_vector[]) {
 
+   if (num_cell_ids == 0) {
+     parent_node->flags = U_IS_LEAF + T_IS_LEAF;
+     return;
+   }
+
    double balance_point[3] = {0.0,0.0,0.0};
 
    // compute balance point
