@@ -1,20 +1,9 @@
 /*
- This file is part of CDO. CDO is a collection of Operators to
- manipulate and analyse Climate model Data.
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
- Copyright (C) 2003-2020 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
- See COPYING file for copying and redistribution conditions.
+  Author: Uwe Schulzweida
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; version 2 of the License.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
 */
-
 #ifndef MODULE_DEFINITIONS_H
 #define MODULE_DEFINITIONS_H /* \cond */
 
@@ -26,8 +15,6 @@ void   *Adisit(void *argument);
 void   *Afterburner(void *argument);
 #define AfterburnerOperators              {"after"}
 
-void   *Arith(void *argument);
-#define ArithOperators                    {"add", "sub", "mul", "div", "min", "max", "atan2", "setmiss"}
 
 void   *Arithc(void *argument);
 #define ArithcOperators                   {"addc", "subc", "mulc", "divc", "minc", "maxc", "mod"}
@@ -98,12 +85,18 @@ void   *Consecstat(void *argument);
 void   *Copy(void *argument);
 #define CopyOperators                     {"copy", "selall", "szip"}
 
+void   *DCW_util(void *argument);
+#define DCW_utilOperators                 {"dcw"}
+
 void   *Deltat(void *argument);
 #define DeltatOperators                   {"deltat", "timederivative"}
 
 void   *Deltime(void *argument);
 #define DeltimeOperators                  {"delday", "del29feb"}
 
+void   *Depth(void *argument);
+#define DepthOperators                    {"zsdepth"}
+
 void   *Derivepar(void *argument);
 #define DeriveparOperators                {"gheight", "sealevelpressure"}
 
@@ -119,9 +112,6 @@ void   *Distgrid(void *argument);
 void   *Duplicate(void *argument);
 #define DuplicateOperators                {"duplicate"}
 
-void   *Echam5ini(void *argument);
-#define Echam5iniOperators                {"import_e5ml", "import_e5res", "export_e5ml", "export_e5res"}
-
 void   *Enlarge(void *argument);
 #define EnlargeOperators                  {"enlarge"}
 
@@ -129,7 +119,7 @@ void   *Enlargegrid(void *argument);
 #define EnlargegridOperators              {"enlargegrid"}
 
 void   *Ensstat(void *argument);
-#define EnsstatOperators                  {"ensrange", "ensmin", "ensmax", "enssum", "ensmean", "ensavg", "ensvar", "ensvar1", "ensstd", "ensstd1", "ensskew", "enskurt", "enspctl"}
+#define EnsstatOperators                  {"ensrange", "ensmin", "ensmax", "enssum", "ensmean", "ensavg", "ensvar", "ensvar1", "ensstd", "ensstd1", "ensskew", "enskurt", "ensmedian", "enspctl"}
 
 void   *Ensstat3(void *argument);
 #define Ensstat3Operators                 {"ensrkhistspace", "ensrkhisttime", "ensroc"}
@@ -171,7 +161,7 @@ void   *Fldrms(void *argument);
 #define FldrmsOperators                   {"fldrms"}
 
 void   *Fldstat(void *argument);
-#define FldstatOperators                  {"fldrange", "fldmin", "fldmax", "fldsum", "fldint", "fldmean", "fldavg", "fldstd", "fldstd1", "fldvar", "fldvar1", "fldskew", "fldkurt", "fldpctl"}
+#define FldstatOperators                  {"fldrange", "fldmin", "fldmax", "fldsum", "fldint", "fldmean", "fldavg", "fldstd", "fldstd1", "fldvar", "fldvar1", "fldskew", "fldkurt", "fldmedian", "fldpctl"}
 
 void   *Fldstat2(void *argument);
 #define FldcorOperators                   {"fldcor"}
@@ -187,7 +177,7 @@ void   *Gradsdes(void *argument);
 #define GradsdesOperators                 {"gradsdes", "dumpmap"}
 
 void   *Gridboxstat(void *argument);
-#define GridboxstatOperators              {"gridboxrange", "gridboxmin", "gridboxmax", "gridboxsum", "gridboxmean", "gridboxavg", "gridboxstd", "gridboxstd1", "gridboxvar", "gridboxvar1", "gridboxskew", "gridboxkurt"}
+#define GridboxstatOperators              {"gridboxrange", "gridboxmin", "gridboxmax", "gridboxsum", "gridboxmean", "gridboxavg", "gridboxstd", "gridboxstd1", "gridboxvar", "gridboxvar1", "gridboxskew", "gridboxkurt", "gridboxmedian"}
 
 void   *Gridcell(void *argument);
 #define GridcellOperators                 {"gridarea", "gridweights", "gridmask", "griddx", "griddy", "gridcellidx"}
@@ -249,9 +239,6 @@ void   *Invert(void *argument);
 void   *Invertlev(void *argument);
 #define InvertlevOperators                {"invertlev"}
 
-void   *Isosurface(void *argument);
-#define IsosurfaceOperators               {"isosurface", "bottomvalue", "topvalue"}
-
 void   *Lic(void *argument);
 #define LicOperators                      {"lic"}
 
@@ -278,7 +265,7 @@ void   *Mergetime(void *argument);
 #define MergetimeOperators                {"mergetime"}
 
 void   *Merstat(void *argument);
-#define MerstatOperators                  {"merrange", "mermin", "mermax", "mersum", "mermean", "meravg", "merstd", "merstd1", "mervar", "mervar1", "merskew", "merkurt", "merpctl"}
+#define MerstatOperators                  {"merrange", "mermin", "mermax", "mersum", "mermean", "meravg", "merstd", "merstd1", "mervar", "mervar1", "merskew", "merkurt", "mermedian", "merpctl"}
 
 void   *Monarith(void *argument);
 #define MonarithOperators                 {"monadd", "monsub", "monmul", "mondiv"}
@@ -303,7 +290,7 @@ void   *Output(void *argument);
 #define OutputtabOperators                {"outputtab"}
  
 void   *Outputgmt(void *argument);
-#define OutputgmtOperators                {"gmtxyz", "gmtcells", "outputcenter2", "outputcentercpt", "outputboundscpt", "outputvector", "outputtri", "outputvrml"}
+#define OutputgmtOperators                {"gmtxyz", "gmtcells", "outputcenter2", "outputcentercpt", "outputboundscpt", "outputvector", "outputtri", "outputvrml", "outputkml"}
 
 void   *Pack(void *argument);
 #define PackOperators                     {"pack"}
@@ -330,7 +317,7 @@ void   *Remap(void *argument);
 #define RemapnnOperators                  {"remapnn", "gennn"}
 #define RemapdisOperators                 {"remapdis", "gendis"}
 #define RemapconOperators                 {"remapcon", "gencon"}
-#define Remapycon2Operators               {"remapycon2", "genycon2"}
+#define Remapycon2Operators               {"remapycon2test", "genycon2test"}
 #define RemapsconOperators                {"remapscon", "genscon"}
 #define Remapcon2Operators                {"remapcon2", "gencon2"}
 #define RemaplafOperators                 {"remaplaf", "genlaf"}
@@ -343,7 +330,7 @@ void   *Remapeta(void *argument);
 #define RemapetaOperators                 {"remapeta", "remapeta_s", "remapeta_z"}
 
 void   *Remapstat(void *argument);
-#define RemapstatOperators                {"remaprange", "remapmin", "remapmax", "remapsum", "remapmean", "remapavg", "remapstd", "remapstd1", "remapvar", "remapvar1", "remapskew", "remapkurt"}
+#define RemapstatOperators                {"remaprange", "remapmin", "remapmax", "remapsum", "remapmean", "remapavg", "remapstd", "remapstd1", "remapvar", "remapvar1", "remapskew", "remapkurt", "remapmedian"}
 
 void   *Replace(void *argument);
 #define ReplaceOperators                  {"replace"}
@@ -399,6 +386,9 @@ void   *Selrec(void *argument);
 void   *Selregion(void *argument);
 #define SelregionOperators                {"selcircle"}
 
+void   *Selsurface(void *argument);
+#define SelsurfaceOperators               {"isosurface", "bottomvalue", "topvalue"}
+
 void   *Seltime(void *argument);
 #define SeltimeOperators                  {"seltimestep", "selyear", "selseason", "selmonth", "selday", "selhour", "seldate", "seltime", "selsmon"}
 
@@ -414,12 +404,12 @@ void   *Setattribute(void *argument);
 void   *Setbox(void *argument);
 #define SetboxOperators                   {"setclonlatbox", "setcindexbox"}
 
-void   *Setgatt(void *argument);
-#define SetgattOperators                  {"setgatt", "setgatts"}
-
 void   *Setgrid(void *argument);
 #define SetgridOperators                  {"setgrid", "setgridtype", "setgridarea", "setgridmask", "unsetgridmask", "setgridnumber", "setgriduri", "usegridnumber", "setprojparams"}
 
+void   *Setgridcell(void *argument);
+#define SetgridcellOperators              {"setgridcell"}
+
 void   *Sethalo(void *argument);
 #define SethaloOperators                  {"sethalo", "tpnhalo"}
 
@@ -451,7 +441,7 @@ void   *Showattribute(void *argument);
 #define ShowattributeOperators            {"showattribute", "showattsvar"}
 
 void   *Sinfo(void *argument);
-#define SinfoOperators                    {"sinfo", "sinfop", "sinfon", "sinfoc", "seinfo", "seinfop", "seinfon", "seinfoc"}
+#define SinfoOperators                    {"sinfo", "sinfop", "sinfon", "sinfoc", "seinfo", "seinfop", "seinfon", "seinfoc", "xsinfo", "xsinfop", "xsinfon", "xsinfoc"}
 
 void   *Smooth(void *argument);
 #define SmoothOperators                   {"smooth", "smooth9"}
@@ -591,6 +581,9 @@ void   *Vertintgh(void *argument);
 void   *Vertintml(void *argument);
 #define VertintmlOperators                {"ml2pl", "ml2hl", "ml2plx", "ml2hlx", "ml2pl_lp", "ml2hl_lp", "ml2plx_lp", "ml2hlx_lp"}
 
+void   *Vertintzs(void *argument);
+#define VertintzsOperators                {"zs2zl", "zs2zlx"}
+
 void   *Vertstat(void *argument);
 #define VertstatOperators                 {"vertrange", "vertmin", "vertmax", "vertsum", "vertint", "vertmean", "vertavg", "vertstd", "vertstd1", "vertvar", "vertvar1"}
 
@@ -660,7 +653,7 @@ void   *Yseasstat(void *argument);
 #define YseasstatOperators                {"yseasrange", "yseasmin", "yseasmax", "yseassum", "yseasmean", "yseasavg", "yseasstd", "yseasstd1", "yseasvar", "yseasvar1"}
 
 void   *Zonstat(void *argument);
-#define ZonstatOperators                  {"zonrange", "zonmin", "zonmax", "zonsum", "zonmean", "zonavg", "zonstd", "zonstd1", "zonvar", "zonvar1", "zonskew", "zonkurt", "zonpctl"}
+#define ZonstatOperators                  {"zonrange", "zonmin", "zonmax", "zonsum", "zonmean", "zonavg", "zonstd", "zonstd1", "zonvar", "zonvar1", "zonskew", "zonkurt", "zonmedian", "zonpctl"}
 
 //------------------------------
 
