@@ -1,5 +1,11 @@
+/*
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
-#include "array.h"
+  Author: Uwe Schulzweida
+
+*/
+
+#include "field.h"
 #include "process_int.h"
 #include "cdo_wtime.h"
 #include "cdo_options.h"
@@ -30,7 +36,7 @@ remapFirstOrder(Varray<T> &dst_array, const RemapVars &rv, const Varray<T> &src_
   if (links.option)
     {
 #ifdef HAVE_OPENMP4
-#pragma omp parallel for simd default(none) shared(num_links, dst_array, dst_add)
+#pragma omp parallel for simd default(shared) schedule(static)
 #endif
       for (size_t n = 0; n < num_links; ++n) dst_array[dst_add[n]] = static_cast<T>(0.0);
 
@@ -41,8 +47,8 @@ remapFirstOrder(Varray<T> &dst_array, const RemapVars &rv, const Varray<T> &src_
           const auto &windex = links.w_index[j];
           auto nlinks = links.num_links[j];
 
-#ifdef HAVE_OPENMP4
-#pragma omp parallel for simd default(none) shared(nlinks, dst_array, src_array, dst_addx, src_addx, map_wts, num_wts, windex)
+#ifdef _OPENMP
+#pragma omp parallel for default(shared) schedule(static)
 #endif
           for (size_t n = 0; n < nlinks; ++n)
             {
@@ -60,7 +66,7 @@ remapFirstOrder(Varray<T> &dst_array, const RemapVars &rv, const Varray<T> &src_
           if (lpv == 1)
             {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(dst_array, src_array, dst_add, src_add, map_wts, nlinks)
+#pragma omp parallel for default(shared) schedule(static)
 #endif
               for (size_t n = 0; n < nlinks; ++n)
                 {
@@ -70,7 +76,7 @@ remapFirstOrder(Varray<T> &dst_array, const RemapVars &rv, const Varray<T> &src_
           else if (lpv == 4)
             {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(dst_array, src_array, dst_add, src_add, map_wts, num_wts, nlinks)
+#pragma omp parallel for default(shared) schedule(static)
 #endif
               for (size_t n = 0; n < nlinks; ++n)
                 {
@@ -84,7 +90,7 @@ remapFirstOrder(Varray<T> &dst_array, const RemapVars &rv, const Varray<T> &src_
           else
             {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(dst_array, src_array, dst_add, src_add, map_wts, num_wts, nlinks, lpv)
+#pragma omp parallel for default(shared) schedule(static)
 #endif
               for (size_t n = 0; n < nlinks; ++n)
                 {
@@ -153,8 +159,7 @@ remapSecondOrder(Varray<T> &dst_array, const RemapVars &rv, const Varray<T> &src
 
 template <typename T>
 static void
-remap(Varray<T> &dst_array, T missval, size_t dst_size, const RemapVars &rv, const Varray<T> &src_array,
-      RemapGradients &gradients)
+remap(Varray<T> &dst_array, T missval, size_t dst_size, const RemapVars &rv, const Varray<T> &src_array, RemapGradients &gradients)
 {
   /*
     Input arrays:
@@ -182,7 +187,7 @@ remap(Varray<T> &dst_array, T missval, size_t dst_size, const RemapVars &rv, con
   const bool firstOrder = gradients.grad_lat.size() == 0;
 
 #ifdef HAVE_OPENMP4
-#pragma omp parallel for simd default(none) shared(dst_size, dst_array, missval)
+#pragma omp parallel for simd default(shared) schedule(static)
 #endif
   for (size_t n = 0; n < dst_size; ++n) dst_array[n] = missval;
 
@@ -197,7 +202,7 @@ remap(Varray<T> &dst_array, T missval, size_t dst_size, const RemapVars &rv, con
       remapSecondOrder(dst_array, rv, src_array, gradients);
     }
 
-  if (Options::cdoVerbose) cdoPrint("Remap: %.2f seconds", cdo_get_wtime() - start);
+  if (Options::cdoVerbose) cdo_print("Remap: %.2f seconds", cdo_get_wtime() - start);
 
   if (Options::Timer) timer_stop(timer_remap);
 }
@@ -206,7 +211,7 @@ void
 remap(Field &field2, double missval, size_t gridsize2, const RemapVars &rv, const Field &field1, RemapGradients &gradients)
 {
   if (field1.memType == MemType::Float)
-    remap(field2.vec_f, (float)missval, gridsize2, rv, field1.vec_f, gradients);
+    remap(field2.vec_f, (float) missval, gridsize2, rv, field1.vec_f, gradients);
   else
     remap(field2.vec_d, missval, gridsize2, rv, field1.vec_d, gradients);
 }
@@ -271,7 +276,7 @@ remap_laf(Varray<T> &dst_array, T missval, size_t dst_size, const RemapVars &rv,
   const auto &dst_add = rv.tgt_cell_add;  // destination address for each link
   const auto &src_add = rv.src_cell_add;  // source      address for each link
 
-  varrayFill(dst_size, dst_array, missval);
+  varray_fill(dst_size, dst_array, missval);
 
   if (num_links == 0) return;
 
@@ -289,20 +294,18 @@ remap_laf(Varray<T> &dst_array, T missval, size_t dst_size, const RemapVars &rv,
     if (DBL_IS_EQUAL(dst_array[dst_add[n]], missval)) dst_array[dst_add[n]] = 0.0;
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(dst_size, src_cls2, src_wts2, num_links, dst_add, src_add, src_array, map_wts, \
-                                              num_wts, dst_array, max_cls) schedule(dynamic, 1)
+#pragma omp parallel for default(shared) schedule(dynamic, 1)
 #endif
   for (size_t i = 0; i < dst_size; ++i)
     {
-      size_t k;
-      size_t ncls;
+      size_t k, ncls;
 #ifdef _OPENMP
       const auto ompthID = cdo_omp_get_thread_num();
       auto &src_cls = src_cls2[ompthID];
       auto &src_wts = src_wts2[ompthID];
 #endif
-      varrayFill(src_cls, static_cast<T>(0.0));
-      varrayFill(src_wts, 0.0);
+      varray_fill(src_cls, static_cast<T>(0.0));
+      varray_fill(src_wts, 0.0);
       /*
       ncls = 0;
       for ( n = 0; n < num_links; n++ )
@@ -375,7 +378,7 @@ remap_laf(Varray<T> &dst_array, T missval, size_t dst_size, const RemapVars &rv,
                 }
             }
 
-          // for (k = 0; k < ncls; ++k) printf("   k, src_wts[k],  src_cls[k] %zu %g %g\n", k, src_wts[k],  src_cls[k]);
+          // for (k = 0; k < ncls; ++k) printf(" i  k, src_wts[k],  src_cls[k] %zu %zu %g %g\n", i, k, src_wts[k],  src_cls[k]);
           // printf("imax, src_wts[imax],  src_cls[imax] %zu %zu %g %g\n", i , imax, src_wts[imax],  src_cls[imax]);
           dst_array[i] = src_cls[imax];
         }
@@ -386,7 +389,7 @@ void
 remap_laf(Field &field2, double missval, size_t gridsize2, const RemapVars &rv, const Field &field1)
 {
   if (field1.memType == MemType::Float)
-    remap_laf(field2.vec_f, (float)missval, gridsize2, rv, field1.vec_f);
+    remap_laf(field2.vec_f, (float) missval, gridsize2, rv, field1.vec_f);
   else
     remap_laf(field2.vec_d, missval, gridsize2, rv, field1.vec_d);
 }
@@ -430,8 +433,7 @@ remap_avg(Varray<T> &dst_array, T missval, size_t dst_size, const RemapVars &rv,
   */
   /*
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(missval, dst_size, num_links, dst_add, src_add, src_array, map_wts, \
-                                              num_wts, dst_array) schedule(dynamic, 1)
+#pragma omp parallel for default(shared) schedule(dynamic, 1)
 #endif
   */
   size_t max_values = 0;
@@ -487,13 +489,13 @@ void
 remap_avg(Field &field2, double missval, size_t gridsize2, const RemapVars &rv, const Field &field1)
 {
   if (field1.memType == MemType::Float)
-    remap_avg(field2.vec_f, (float)missval, gridsize2, rv, field1.vec_f);
+    remap_avg(field2.vec_f, (float) missval, gridsize2, rv, field1.vec_f);
   else
     remap_avg(field2.vec_d, missval, gridsize2, rv, field1.vec_d);
 }
 
 void
-remapVarsInit(RemapMethod mapType, int remapOrder, RemapVars &rv)
+remap_vars_init(RemapMethod mapType, int remapOrder, RemapVars &rv)
 {
   // Initialize all pointer
   if (!rv.pinit) rv.pinit = true;
@@ -515,7 +517,7 @@ remapVarsInit(RemapMethod mapType, int remapOrder, RemapVars &rv)
 }
 
 void
-remapVarsEnsureSize(RemapVars &rv, size_t size)
+remap_vars_ensure_size(RemapVars &rv, size_t size)
 {
   if (size >= rv.max_links)
     {
@@ -528,7 +530,7 @@ remapVarsEnsureSize(RemapVars &rv, size_t size)
 }
 
 void
-remapVarsResize(RemapVars &rv, size_t size)
+remap_vars_resize(RemapVars &rv, size_t size)
 {
   rv.max_links = size;
 
@@ -538,13 +540,13 @@ remapVarsResize(RemapVars &rv, size_t size)
 }
 
 void
-remapVarsReorder(RemapVars &rv)
+remap_vars_reorder(RemapVars &rv)
 {
   size_t nval = 0, num_blks = 0;
 
   const auto num_links = rv.num_links;
 
-  printf("remapVarsReorder\n");
+  printf("remap_vars_reorder\n");
   printf("  num_links %zu\n", num_links);
   rv.links.option = true;
 
@@ -614,16 +616,16 @@ remapVarsReorder(RemapVars &rv)
 }
 
 void
-remapVarsFree(RemapVars &rv)
+remap_vars_free(RemapVars &rv)
 {
   if (rv.pinit)
     {
       rv.pinit = false;
       rv.sort_add = false;
 
-      varrayFree(rv.src_cell_add);
-      varrayFree(rv.tgt_cell_add);
-      varrayFree(rv.wts);
+      varray_free(rv.src_cell_add);
+      varray_free(rv.tgt_cell_add);
+      varray_free(rv.wts);
 
       if (rv.links.option)
         {
@@ -631,27 +633,27 @@ remapVarsFree(RemapVars &rv)
 
           if (rv.links.num_blks)
             {
-              varrayFree(rv.links.num_links);
+              varray_free(rv.links.num_links);
               const auto num_blks = rv.links.num_blks;
               for (size_t i = 0; i < num_blks; ++i)
                 {
-                  varrayFree(rv.links.src_add[i]);
-                  varrayFree(rv.links.dst_add[i]);
-                  varrayFree(rv.links.w_index[i]);
+                  varray_free(rv.links.src_add[i]);
+                  varray_free(rv.links.dst_add[i]);
+                  varray_free(rv.links.w_index[i]);
                 }
-              varrayFree(rv.links.src_add);
-              varrayFree(rv.links.dst_add);
-              varrayFree(rv.links.w_index);
+              varray_free(rv.links.src_add);
+              varray_free(rv.links.dst_add);
+              varray_free(rv.links.w_index);
             }
         }
     }
   else
     fprintf(stderr, "%s Warning: vars not initialized!\n", __func__);
 
-} // remapVarsFree
+}  // remap_vars_free
 
 void
-remapVarsCheckWeights(const RemapVars &rv)
+remap_vars_check_weights(const RemapVars &rv)
 {
   const auto num_links = rv.num_links;
   const auto num_wts = rv.num_wts;
@@ -663,9 +665,9 @@ remapVarsCheckWeights(const RemapVars &rv)
   for (size_t n = 0; n < num_links; ++n)
     {
       if (wts[n * num_wts] < -0.01)
-        cdoPrint("Map weight < 0! grid1idx=%zu grid2idx=%zu nlink=%zu wts=%g", src_add[n], tgt_add[n], n, wts[n * num_wts]);
+        cdo_print("Map weight < 0! grid1idx=%zu grid2idx=%zu nlink=%zu wts=%g", src_add[n], tgt_add[n], n, wts[n * num_wts]);
 
       if (normOpt != NormOpt::NONE && wts[n * num_wts] > 1.01)
-        cdoPrint("Map weight > 1! grid1idx=%zu grid2idx=%zu nlink=%zu wts=%g", src_add[n], tgt_add[n], n, wts[n * num_wts]);
+        cdo_print("Map weight > 1! grid1idx=%zu grid2idx=%zu nlink=%zu wts=%g", src_add[n], tgt_add[n], n, wts[n * num_wts]);
     }
 }
